==> landtax-1.0.0-20161009.022418-24-sources.jar: cn/gtmap/landtax/printexcel/access/ExcelBean.java <==
package cn.gtmap.landtax.printexcel.access;

import java.io.Serializable;
import java.util.HashMap;

import javax.servlet.http.HttpServletRequest;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

@SuppressWarnings("serial")
public class ExcelBean implements Serializable {
	Log log =LogFactory.getLog(getClass().getName());
	public ExcelBean(){
	
	}
	/**
	 * excel模板的名称
	 */
	private String excelTemplate=null;
	/**
	 * excel的xml配置文件的名称
	 */
	private String excelXml=null;
	/**
	 * key-对应xml中的group的id
	 * value－对应list对象
	 * @return
	 */
	private HashMap groupMap=null;
	/**
	 * pojo组成的Object数组
	 * @return
	 */
	private Object[] pojos=null;
	/**
	 * 自定义控件组成的HashMap
	 * @return
	 */
	public String getExcelTemplate() {
		return excelTemplate;
	}
	public void setExcelTemplate(String excelTemplate) {
		this.excelTemplate = excelTemplate;
	}
	public Object[] getPojos() {
		return pojos;
	}
	public void setPojos(Object[] pojos) {
		this.pojos = pojos;
	}
	public String getExcelXml() {
		return excelXml;
	}
	public void setExcelXml(String excelXml) {
		this.excelXml = excelXml;
	}
	public void printExcel(HttpServletRequest request) {
		WriteSheet ws=new WriteSheet();
		//request.setAttribute("jsForExcel",ws.execute(this.groupMap,this.pojos,this.excelTemplate,this.excelXml,request));
		request.setAttribute("FileDownLoadURL",ws.execute(this.groupMap,this.pojos,this.excelTemplate,this.excelXml,request));
	}
	public HashMap getGroupMap() {
		return groupMap;
	}
	public void setGroupMap(HashMap groupMap) {
		this.groupMap = groupMap;
	}	
}

==> landtax-1.0.0-20180601.023313-26-sources.jar: cn/gtmap/landtax/printexcel/access/ExcelBean.java <==
package cn.gtmap.landtax.printexcel.access;

import java.io.Serializable;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.springframework.web.multipart.MultipartFile;

@SuppressWarnings("serial")
public class ExcelBean implements Serializable {
	Log log =LogFactory.getLog(getClass().getName());
	public ExcelBean(){
	
	}
	/**
	 * excel模板的名称
	 */
	private String excelTemplate=null;
	/**
	 * excel的xml配置文件的名称
	 */
	private String excelXml=null;
	/**
	 * key-对应xml中的group的id
	 * value－对应list对象
	 * @return
	 */
	private HashMap groupMap=null;
	/**
	 * pojo组成的Object数组
	 * @return
	 */
	private Object[] pojos=null;
	/**
	 * 自定义控件组成的HashMap
	 * @return
	 */
	public String getExcelTemplate() {
		return excelTemplate;
	}
	public void setExcelTemplate(String excelTemplate) {
		this.excelTemplate = excelTemplate;
	}
	public Object[] getPojos() {
		return pojos;
	}
	public void setPojos(Object[] pojos) {
		this.pojos = pojos;
	}
	public String getExcelXml() {
		return excelXml;
	}
	public void setExcelXml(String excelXml) {
		this.excelXml = excelXml;
	}
	public void printExcel(HttpServletRequest request) {
		WriteSheet ws=new WriteSheet();
		//request.setAttribute("jsForExcel",ws.execute(this.groupMap,this.pojos,this.excelTemplate,this.excelXml,request));
		request.setAttribute("FileDownLoadURL",ws.execute(this.groupMap,this.pojos,this.excelTemplate,this.excelXml,request));
	}

    /**
     * 读取EXCEL文件
     * @param file EXCEL文件
     * @param fieldNames 字段列
     */
    public List<Map<String, String>> readExcel(MultipartFile file, String[] fieldNames) {
        ReadSheet rs=new ReadSheet();
        return rs.execute(file, fieldNames);
    }

	public HashMap getGroupMap() {
		return groupMap;
	}
	public void setGroupMap(HashMap groupMap) {
		this.groupMap = groupMap;
	}	
}
